@@ -258,6 +258,10 @@ function install_redis {
 
 }
 
+function stop_redis {
+    stop_service redis || true
+}
+
 function uninstall_redis {
     if is_fedora; then
         uninstall_package redis
@@ -266,9 +270,6 @@ function uninstall_redis {
     elif is_suse; then
         uninstall_package redis
     fi
-
-    stop_service redis
-
 }
 
 function octavia_configure {
@@ -298,6 +299,7 @@ function octavia_configure {
     iniset $OCTAVIA_CONF database connection "mysql+pymysql://${DATABASE_USER}:${DATABASE_PASSWORD}@${DATABASE_HOST}:3306/octavia"
     if [[ ${OCTAVIA_ENABLE_AMPHORAV2_JOBBOARD} == True ]]; then
         iniset $OCTAVIA_CONF task_flow persistence_connection "mysql+pymysql://${DATABASE_USER}:${DATABASE_PASSWORD}@${DATABASE_HOST}:3306/octavia_persistence"
+        iniset $OCTAVIA_CONF task_flow jobboard_enabled True
     fi
     # Configure keystone auth_token for all users
     configure_keystone_authtoken_middleware $OCTAVIA_CONF octavia
@@ -658,6 +660,10 @@ function octavia_stop {
     else
         die "Unknown network controller. Please define octavia_delete_network_interface_device"
     fi
+
+    if [[ ${OCTAVIA_ENABLE_AMPHORAV2_JOBBOARD} == True ]]; then
+        stop_redis
+    fi
 }
 
 function octavia_cleanup {
