@@ -19,22 +19,10 @@ from octavia.amphorae.drivers import driver_base
 LOG = logging.getLogger(__name__)
 
 
-class LoggingUpdate(object):
-    def update_stats(self, stats):
-        LOG.debug("Amphora %s no-op, update stats %s",
-                  self.__class__.__name__, stats)
-        self.stats = stats
-
-    def update_health(self, health):
-        LOG.debug("Amphora %s no-op, update health %s",
-                  self.__class__.__name__, health)
-        self.health = health
-
-
 class NoopManager(object):
 
     def __init__(self):
-        super(NoopManager, self).__init__()
+        super().__init__()
         self.amphoraconfig = {}
 
     def update_amphora_listeners(self, loadbalancer, amphora, timeout_dict):
@@ -58,7 +46,7 @@ class NoopManager(object):
                                               'active')
 
     def start(self, loadbalancer, amphora=None, timeout_dict=None):
-        LOG.debug("Amphora %s no-op, start listeners, lb %s, amp %s"
+        LOG.debug("Amphora %s no-op, start listeners, lb %s, amp %s "
                   "timeouts %s", self.__class__.__name__, loadbalancer.id,
                   amphora, timeout_dict)
         self.amphoraconfig[
@@ -135,7 +123,7 @@ class NoopAmphoraLoadBalancerDriver(
     driver_base.AmphoraLoadBalancerDriver,
         driver_base.VRRPDriverMixin):
     def __init__(self):
-        super(NoopAmphoraLoadBalancerDriver, self).__init__()
+        super().__init__()
         self.driver = NoopManager()
 
     def update_amphora_listeners(self, loadbalancer, amphora, timeout_dict):
