@@ -31,7 +31,7 @@ class RootController(object):
     """The controller with which the pecan wsgi app should be created."""
 
     def __init__(self):
-        super(RootController, self).__init__()
+        super().__init__()
         setattr(self, 'v2.0', v2_controller.V2Controller())
         setattr(self, 'v2', v2_controller.V2Controller())
         if CONF.api_settings.healthcheck_enabled:
@@ -109,10 +109,31 @@ class RootController(object):
         # Availability Zones
         self._add_a_version(versions, 'v2.14', 'v2', 'SUPPORTED',
                             '2019-11-10T00:00:00Z', host_url)
-        # TLS version and cipher options
+        # TLS cipher options
         self._add_a_version(versions, 'v2.15', 'v2', 'SUPPORTED',
                             '2020-03-10T00:00:00Z', host_url)
         # Additional UDP Healthcheck Types (HTTP/TCP)
-        self._add_a_version(versions, 'v2.16', 'v2', 'CURRENT',
+        self._add_a_version(versions, 'v2.16', 'v2', 'SUPPORTED',
                             '2020-03-15T00:00:00Z', host_url)
+        # Listener TLS versions
+        self._add_a_version(versions, 'v2.17', 'v2', 'SUPPORTED',
+                            '2020-04-29T00:00:00Z', host_url)
+        # Pool TLS versions
+        self._add_a_version(versions, 'v2.18', 'v2', 'SUPPORTED',
+                            '2020-04-29T01:00:00Z', host_url)
+        # Add quota support to octavia's l7policy and l7rule
+        self._add_a_version(versions, 'v2.19', 'v2', 'SUPPORTED',
+                            '2020-05-12T00:00:00Z', host_url)
+        # ALPN protocols
+        self._add_a_version(versions, 'v2.20', 'v2', 'SUPPORTED',
+                            '2020-08-02T00:00:00Z', host_url)
+        # Amphora delete
+        self._add_a_version(versions, 'v2.21', 'v2', 'SUPPORTED',
+                            '2020-09-03T00:00:00Z', host_url)
+        # Add PROXYV2 pool protocol
+        self._add_a_version(versions, 'v2.22', 'v2', 'SUPPORTED',
+                            '2020-09-04T00:00:00Z', host_url)
+        # SCTP protocol
+        self._add_a_version(versions, 'v2.23', 'v2', 'CURRENT',
+                            '2020-09-07T00:00:00Z', host_url)
         return {'versions': versions}
