@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia_lib.api.drivers import data_models as driver_dm
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -21,7 +22,6 @@ from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
-from octavia.api.drivers import data_models as driver_dm
 from octavia.api.drivers import driver_factory
 from octavia.api.drivers import utils as driver_utils
 from octavia.api.v2.controllers import base
@@ -41,7 +41,7 @@ class MemberController(base.BaseController):
     RBAC_TYPE = constants.RBAC_MEMBER
 
     def __init__(self, pool_id):
-        super(MemberController, self).__init__()
+        super().__init__()
         self.pool_id = pool_id
 
     @wsme_pecan.wsexpose(member_types.MemberRootResponse, wtypes.text,
@@ -129,11 +129,11 @@ class MemberController(base.BaseController):
                 raise exceptions.DuplicateMemberEntry(
                     ip_address=member_dict.get('ip_address'),
                     port=member_dict.get('protocol_port'))
-        except odb_exceptions.DBError:
+        except odb_exceptions.DBError as e:
             # TODO(blogan): will have to do separate validation protocol
             # before creation or update since the exception messages
             # do not give any information as to what constraint failed
-            raise exceptions.InvalidOption(value='', option='')
+            raise exceptions.InvalidOption(value='', option='') from e
 
     def _validate_pool_id(self, member_id, db_member_pool_id):
         if db_member_pool_id != self.pool_id:
@@ -319,7 +319,7 @@ class MemberController(base.BaseController):
 class MembersController(MemberController):
 
     def __init__(self, pool_id):
-        super(MembersController, self).__init__(pool_id)
+        super().__init__(pool_id)
 
     @wsme_pecan.wsexpose(None, wtypes.text,
                          body=member_types.MembersRootPUT, status_code=202)
