@@ -207,11 +207,15 @@ UPDATE_HEALTH = 'UPDATE_HEALTH'
 
 VALID_LISTENER_POOL_PROTOCOL_MAP = {
     PROTOCOL_TCP: [PROTOCOL_HTTP, PROTOCOL_HTTPS,
-                   PROTOCOL_PROXY, PROTOCOL_TCP],
-    PROTOCOL_HTTP: [PROTOCOL_HTTP, PROTOCOL_PROXY],
-    PROTOCOL_HTTPS: [PROTOCOL_HTTPS, PROTOCOL_PROXY, PROTOCOL_TCP],
-    PROTOCOL_TERMINATED_HTTPS: [PROTOCOL_HTTP, PROTOCOL_PROXY],
-    PROTOCOL_UDP: [PROTOCOL_UDP]}
+                   PROTOCOL_PROXY, lib_consts.PROTOCOL_PROXYV2, PROTOCOL_TCP],
+    PROTOCOL_HTTP: [PROTOCOL_HTTP, PROTOCOL_PROXY,
+                    lib_consts.PROTOCOL_PROXYV2],
+    PROTOCOL_HTTPS: [PROTOCOL_HTTPS, PROTOCOL_PROXY,
+                     lib_consts.PROTOCOL_PROXYV2, PROTOCOL_TCP],
+    PROTOCOL_TERMINATED_HTTPS: [PROTOCOL_HTTP, PROTOCOL_PROXY,
+                                lib_consts.PROTOCOL_PROXYV2],
+    PROTOCOL_UDP: [PROTOCOL_UDP],
+    lib_consts.PROTOCOL_SCTP: [lib_consts.PROTOCOL_SCTP]}
 
 # API Integer Ranges
 MIN_PORT_NUMBER = 1
@@ -788,6 +792,7 @@ AVAILABILITY_ZONE_DATA = 'availability_zone_data'
 # Flavor metadata
 LOADBALANCER_TOPOLOGY = 'loadbalancer_topology'
 COMPUTE_FLAVOR = 'compute_flavor'
+AMP_IMAGE_TAG = 'amp_image_tag'
 
 # TODO(johnsom) move to octavia_lib
 # client certification authorization option
@@ -809,9 +814,15 @@ L4_PROTOCOL_MAP = {
     PROTOCOL_HTTPS: PROTOCOL_TCP,
     PROTOCOL_TERMINATED_HTTPS: PROTOCOL_TCP,
     PROTOCOL_PROXY: PROTOCOL_TCP,
+    lib_consts.PROTOCOL_PROXYV2: PROTOCOL_TCP,
     PROTOCOL_UDP: PROTOCOL_UDP,
+    lib_consts.PROTOCOL_SCTP: lib_consts.PROTOCOL_SCTP,
 }
 
+# Image drivers
+SUPPORTED_IMAGE_DRIVERS = ['image_noop_driver',
+                           'image_glance_driver']
+
 # Volume drivers
 VOLUME_NOOP_DRIVER = 'volume_noop_driver'
 SUPPORTED_VOLUME_DRIVERS = [VOLUME_NOOP_DRIVER,
@@ -834,6 +845,18 @@ CIPHERS_OWASP_SUITE_B = ('TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:'
                          'DHE-RSA-AES128-SHA256:ECDHE-RSA-AES256-SHA384:'
                          'ECDHE-RSA-AES128-SHA256')
 
+TLS_VERSIONS_OWASP_SUITE_B = [lib_consts.TLS_VERSION_1_2,
+                              lib_consts.TLS_VERSION_1_3]
+
+# All supported TLS versions in ascending order (oldest to newest)
+TLS_ALL_VERSIONS = [
+    lib_consts.SSL_VERSION_3,
+    lib_consts.TLS_VERSION_1,
+    lib_consts.TLS_VERSION_1_1,
+    lib_consts.TLS_VERSION_1_2,
+    lib_consts.TLS_VERSION_1_3
+]
+
 VIP_SECURITY_GROUP_PREFIX = 'lb-'
 
 AMP_BASE_PORT_PREFIX = 'octavia-lb-vrrp-'
@@ -843,3 +866,11 @@ OCTAVIA_OWNED = 'octavia_owned'
 # but they should be on the pool. Dealing with it until v3.
 LISTENER_PROTOCOLS_SUPPORTING_HEADER_INSERTION = [PROTOCOL_HTTP,
                                                   PROTOCOL_TERMINATED_HTTPS]
+
+SUPPORTED_ALPN_PROTOCOLS = [lib_consts.ALPN_PROTOCOL_HTTP_2,
+                            lib_consts.ALPN_PROTOCOL_HTTP_1_1,
+                            lib_consts.ALPN_PROTOCOL_HTTP_1_0]
+
+AMPHORA_SUPPORTED_ALPN_PROTOCOLS = [lib_consts.ALPN_PROTOCOL_HTTP_2,
+                                    lib_consts.ALPN_PROTOCOL_HTTP_1_1,
+                                    lib_consts.ALPN_PROTOCOL_HTTP_1_0]
