@@ -128,7 +128,7 @@ class ControllerWorker(object):
                 flow_utils.get_create_amphora_flow,
                 store=store, wait=True)
         except Exception as e:
-            LOG.error('Failed to create an amphora due to: {}'.format(str(e)))
+            LOG.error('Failed to create an amphora due to: %s', str(e))
 
     def delete_amphora(self, amphora_id):
         """Deletes an existing Amphora.
@@ -145,8 +145,8 @@ class ControllerWorker(object):
                 flow_utils.get_delete_amphora_flow,
                 store=store)
         except Exception as e:
-            LOG.error('Failed to delete a amphora {0} due to: {1}'.format(
-                amphora_id, str(e)))
+            LOG.error('Failed to delete a amphora %s due to: %s',
+                      amphora_id, str(e))
             return
         LOG.info('Finished deleting amphora %s.', amphora_id)
 
@@ -434,6 +434,14 @@ class ControllerWorker(object):
             flow_utils.get_update_load_balancer_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_member(self, member):
         """Creates a pool member.
 
@@ -441,8 +449,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoSuitablePool: Unable to find the node pool
         """
-        pool = self._pool_repo.get(db_apis.get_session(),
-                                   id=member[constants.POOL_ID])
+        db_member = self._member_repo.get(db_apis.get_session(),
+                                          id=member[constants.MEMBER_ID])
+        if not db_member:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7member',
+                        member[constants.MEMBER_ID])
+            raise db_exceptions.NoResultFound
+
+        pool = db_member.pool
         load_balancer = pool.load_balancer
         provider_lb = provider_utils.db_loadbalancer_to_provider_loadbalancer(
             load_balancer).to_dict()
@@ -693,6 +708,14 @@ class ControllerWorker(object):
             flow_utils.get_update_pool_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_l7policy(self, l7policy):
         """Creates an L7 Policy.
 
@@ -700,8 +723,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_listener = self._listener_repo.get(
-            db_apis.get_session(), id=l7policy[constants.LISTENER_ID])
+        db_l7policy = self._l7policy_repo.get(
+            db_apis.get_session(), id=l7policy[constants.L7POLICY_ID])
+        if not db_l7policy:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7policy',
+                        l7policy[constants.L7POLICY_ID])
+            raise db_exceptions.NoResultFound
+
+        db_listener = db_l7policy.listener
 
         listeners_dicts = (
             provider_utils.db_listeners_to_provider_dicts_list_of_dicts(
@@ -759,6 +789,14 @@ class ControllerWorker(object):
             flow_utils.get_update_l7policy_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_l7rule(self, l7rule):
         """Creates an L7 Rule.
 
@@ -766,8 +804,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_l7policy = self._l7policy_repo.get(db_apis.get_session(),
-                                              id=l7rule[constants.L7POLICY_ID])
+        db_l7rule = self._l7rule_repo.get(db_apis.get_session(),
+                                          id=l7rule[constants.L7RULE_ID])
+        if not db_l7rule:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7rule',
+                        l7rule[constants.L7RULE_ID])
+            raise db_exceptions.NoResultFound
+
+        db_l7policy = db_l7rule.l7policy
 
         load_balancer = db_l7policy.listener.load_balancer
 
@@ -920,7 +965,8 @@ class ControllerWorker(object):
                              constants.LOADBALANCER: provider_lb_dict,
                              constants.SERVER_GROUP_ID: server_group_id,
                              constants.LOADBALANCER_ID: lb_id,
-                             constants.VIP: vip_dict}
+                             constants.VIP: vip_dict,
+                             constants.AMPHORA_ID: amphora_id}
 
             self.services_controller.run_poster(
                 flow_utils.get_failover_amphora_flow,
@@ -1084,7 +1130,7 @@ class ControllerWorker(object):
         except Exception as e:
             with excutils.save_and_reraise_exception(reraise=False):
                 LOG.exception("LB %(lbid)s failover exception: %(exc)s",
-                              {'lbid': load_balancer_id, 'exc': e})
+                              {'lbid': load_balancer_id, 'exc': str(e)})
                 self._lb_repo.update(
                     db_apis.get_session(), load_balancer_id,
                     provisioning_status=constants.ERROR)
