@@ -104,11 +104,19 @@ def create_listener(listener_dict, lb_id):
     if 'client_authentication' not in listener_dict:
         listener_dict['client_authentication'] = constants.CLIENT_AUTH_NONE
 
-    if (listener_dict['protocol'] == constants.PROTOCOL_TERMINATED_HTTPS and
-            ('tls_ciphers' not in listener_dict or
-             listener_dict['tls_ciphers'] is None)):
-        listener_dict['tls_ciphers'] = (
-            CONF.api_settings.default_listener_ciphers)
+    if listener_dict['protocol'] == constants.PROTOCOL_TERMINATED_HTTPS:
+        if ('tls_ciphers' not in listener_dict or
+                listener_dict['tls_ciphers'] is None):
+            listener_dict['tls_ciphers'] = (
+                CONF.api_settings.default_listener_ciphers)
+        if ('tls_versions' not in listener_dict or
+                listener_dict['tls_versions'] is None):
+            listener_dict['tls_versions'] = (
+                CONF.api_settings.default_listener_tls_versions)
+        if ('alpn_protocols' not in listener_dict or
+                listener_dict['alpn_protocols'] is None):
+            listener_dict['alpn_protocols'] = (
+                CONF.api_settings.default_listener_alpn_protocols)
 
     if listener_dict.get('timeout_client_data') is None:
         listener_dict['timeout_client_data'] = (
@@ -183,8 +191,12 @@ def create_pool(pool_dict, lb_id=None):
         prepped_members = []
         for member_dict in pool_dict.get('members'):
             prepped_members.append(create_member(member_dict, pool_dict['id']))
-    if pool_dict['tls_enabled'] is True and pool_dict['tls_ciphers'] is None:
-        pool_dict['tls_ciphers'] = CONF.api_settings.default_pool_ciphers
+    if pool_dict['tls_enabled'] is True:
+        if pool_dict['tls_ciphers'] is None:
+            pool_dict['tls_ciphers'] = CONF.api_settings.default_pool_ciphers
+        if pool_dict['tls_versions'] is None:
+            pool_dict['tls_versions'] = (
+                CONF.api_settings.default_pool_tls_versions)
     pool_dict[constants.PROVISIONING_STATUS] = constants.PENDING_CREATE
     pool_dict[constants.OPERATING_STATUS] = constants.OFFLINE
     return pool_dict
