@@ -152,6 +152,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             security_group_id=sec_grp_id)
 
         updated_ports = []
+        listener_peer_ports = []
         for listener in load_balancer.listeners:
             if (listener.provisioning_status in [constants.PENDING_DELETE,
                                                  constants.DELETED]):
@@ -171,11 +172,17 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                 port = (listener.protocol_port, protocol, None)
                 updated_ports.append(port)
 
-            # As the peer port will hold the tcp connection for keepalived and
-            # haproxy session synchronization, so here the security group rule
-            # should be just related with tcp protocol only.
-            updated_ports.append(
-                (listener.peer_port, constants.PROTOCOL_TCP.lower(), None))
+            listener_peer_ports.append(listener.peer_port)
+
+        # As the peer port will hold the tcp connection for keepalived and
+        # haproxy session synchronization, so here the security group rule
+        # should be just related with tcp protocol only. To avoid adding
+        # duplicate rules, peer_port info should be added if updated_ports
+        # does not have the peer_port entry with allowed_cidr 0.0.0.0/0
+        tcp_lower = constants.PROTOCOL_TCP.lower()
+        for peer_port in listener_peer_ports:
+            if (peer_port, tcp_lower, "0.0.0.0/0") not in updated_ports:
+                updated_ports.append((peer_port, tcp_lower, None))
 
         # Just going to use port_range_max for now because we can assume that
         # port_range_max and min will be the same since this driver is
@@ -349,9 +356,9 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         try:
             port = self.get_port(vip.port_id)
         except base.PortNotFound:
-            LOG.warning("Can't deallocate VIP because the vip port {0} "
+            LOG.warning("Can't deallocate VIP because the vip port %s "
                         "cannot be found in neutron. "
-                        "Continuing cleanup.".format(vip.port_id))
+                        "Continuing cleanup.", vip.port_id)
             port = None
 
         self._delete_security_group(vip, port)
@@ -565,7 +572,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         except Exception as e:
             LOG.error('Failed to delete port.  Resources may still be in '
                       'use for port: %(port)s due to error: %(except)s',
-                      {constants.PORT: amphora.vrrp_port_id, 'except': e})
+                      {constants.PORT: amphora.vrrp_port_id, 'except': str(e)})
 
     def unplug_vip(self, load_balancer, vip):
         try:
@@ -623,9 +630,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             raise exceptions.MissingVIPSecurityGroup(lb_id=load_balancer.id)
         else:
             LOG.warning('VIP security group missing when updating the VIP for '
-                        'delete on load balancer: {lb_id}. Skipping update '
-                        'because this is for delete.'.format(
-                            lb_id=load_balancer.id))
+                        'delete on load balancer: %s. Skipping update '
+                        'because this is for delete.', load_balancer.id)
 
     def failover_preparation(self, amphora):
         if self.dns_integration_enabled:
