@@ -11,11 +11,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import os
 import subprocess
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from werkzeug import exceptions as wz_exceptions
@@ -38,48 +37,50 @@ FAKE_INTERFACE = 'eth33'
 
 class TestPlug(base.TestCase):
     def setUp(self):
-        super(TestPlug, self).setUp()
+        super().setUp()
         self.mock_platform = mock.patch("distro.id").start()
         self.mock_platform.return_value = "ubuntu"
         self.osutil = osutils.BaseOS.get_os_util()
         self.test_plug = plug.Plug(self.osutil)
         self.addCleanup(self.mock_platform.stop)
 
-    @mock.patch('pyroute2.IPRoute.__enter__', create=True)
+    @mock.patch('pyroute2.IPRoute', create=True)
     def test__interface_by_mac_case_insensitive_ubuntu(self, mock_ipr):
         mock_ipr_instance = mock.MagicMock()
         mock_ipr_instance.link_lookup.return_value = [33]
         mock_ipr_instance.get_links.return_value = ({
             'attrs': [('IFLA_IFNAME', FAKE_INTERFACE)]},)
-        mock_ipr.return_value = mock_ipr_instance
+        mock_ipr().__enter__.return_value = mock_ipr_instance
 
         interface = self.test_plug._interface_by_mac(FAKE_MAC_ADDRESS.upper())
         self.assertEqual(FAKE_INTERFACE, interface)
         mock_ipr_instance.get_links.assert_called_once_with(33)
 
-    @mock.patch('pyroute2.IPRoute.__enter__', create=True)
+    @mock.patch('pyroute2.IPRoute', create=True)
     def test__interface_by_mac_not_found(self, mock_ipr):
         mock_ipr_instance = mock.MagicMock()
         mock_ipr_instance.link_lookup.return_value = []
-        mock_ipr.return_value = mock_ipr_instance
+        mock_ipr().__enter__.return_value = mock_ipr_instance
 
         fd_mock = mock.mock_open()
         open_mock = mock.Mock()
+        isfile_mock = mock.Mock()
         with mock.patch('os.open', open_mock), mock.patch.object(
-                os, 'fdopen', fd_mock):
+                os, 'fdopen', fd_mock), mock.patch.object(
+                os.path, 'isfile', isfile_mock):
             self.assertRaises(wz_exceptions.HTTPException,
                               self.test_plug._interface_by_mac,
                               FAKE_MAC_ADDRESS.upper())
         open_mock.assert_called_once_with('/sys/bus/pci/rescan', os.O_WRONLY)
         fd_mock().write.assert_called_once_with('1')
 
-    @mock.patch('pyroute2.IPRoute.__enter__', create=True)
+    @mock.patch('pyroute2.IPRoute', create=True)
     def test__interface_by_mac_case_insensitive_rh(self, mock_ipr):
         mock_ipr_instance = mock.MagicMock()
         mock_ipr_instance.link_lookup.return_value = [33]
         mock_ipr_instance.get_links.return_value = ({
             'attrs': [('IFLA_IFNAME', FAKE_INTERFACE)]},)
-        mock_ipr.return_value = mock_ipr_instance
+        mock_ipr().__enter__.return_value = mock_ipr_instance
 
         with mock.patch('distro.id', return_value='centos'):
             osutil = osutils.BaseOS.get_os_util()
@@ -209,7 +210,7 @@ class TestPlug(base.TestCase):
 
 class TestPlugNetwork(base.TestCase):
     def setUp(self):
-        super(TestPlugNetwork, self).setUp()
+        super().setUp()
         self.mock_platform = mock.patch("distro.id").start()
 
     def __generate_network_file_text_static_ip(self):
@@ -240,10 +241,8 @@ class TestPlugNetwork(base.TestCase):
             'down route del -net {dest1} gw {nexthop} dev {netns_interface}\n'
             'up route add -net {dest2} gw {nexthop} dev {netns_interface}\n'
             'down route del -net {dest2} gw {nexthop} dev {netns_interface}\n'
-            'post-up /sbin/iptables -t nat -A POSTROUTING -p udp -o '
-            'eth1234 -j MASQUERADE\n'
-            'post-down /sbin/iptables -t nat -D POSTROUTING -p udp -o eth1234 '
-            '-j MASQUERADE\n')
+            'post-up /usr/local/bin/udp-masquerade.sh add ipv4 eth1234\n'
+            'post-down /usr/local/bin/udp-masquerade.sh delete ipv4 eth1234\n')
 
         template_port = osutils.j2_env.get_template('plug_port_ethX.conf.j2')
         text = self.test_plug._osutils._generate_network_file_text(
@@ -294,10 +293,10 @@ class TestPlugNetwork(base.TestCase):
             'down route del -net {dest1} gw {nexthop} dev {netns_interface}\n'
             'up route add -net {dest2} gw {nexthop} dev {netns_interface}\n'
             'down route del -net {dest2} gw {nexthop} dev {netns_interface}\n'
-            'post-up /sbin/iptables -t nat -A POSTROUTING -p udp -o '
-            '{netns_interface} -j MASQUERADE\n'
-            'post-down /sbin/iptables -t nat -D POSTROUTING -p udp -o '
-            '{netns_interface} -j MASQUERADE\n'
+            'post-up /usr/local/bin/udp-masquerade.sh add ipv4 '
+            '{netns_interface}\n'
+            'post-down /usr/local/bin/udp-masquerade.sh delete ipv4 '
+            '{netns_interface}\n'
             '\n\n# Generated by Octavia agent\n'
             'auto {netns_interface}\n'
             'iface {netns_interface} inet6 static\n'
@@ -305,10 +304,10 @@ class TestPlugNetwork(base.TestCase):
             'broadcast {broadcast_ipv6}\n'
             'netmask {netmask_ipv6}\n'
             'mtu {mtu}\n'
-            'post-up /sbin/ip6tables -t nat -A POSTROUTING -p udp -o '
-            '{netns_interface} -j MASQUERADE\n'
-            'post-down /sbin/ip6tables -t nat -D POSTROUTING -p udp -o '
-            '{netns_interface} -j MASQUERADE\n')
+            'post-up /usr/local/bin/udp-masquerade.sh add ipv6 '
+            '{netns_interface}\n'
+            'post-down /usr/local/bin/udp-masquerade.sh delete ipv6 '
+            '{netns_interface}\n')
 
         template_port = osutils.j2_env.get_template('plug_port_ethX.conf.j2')
         text = self.test_plug._osutils._generate_network_file_text(
