@@ -470,7 +470,7 @@ RET_UDP_POOL = {
     'id': 'sample_pool_id_1',
     'enabled': True,
     'health_monitor': UDP_HEALTH_MONITOR_NO_SCRIPT,
-    'lb_algorithm': 'rr',
+    'lb_algorithm': 'wrr',
     'members': [UDP_MEMBER_1, UDP_MEMBER_2],
     'protocol': 'udp',
     'session_persistence': UDP_SOURCE_IP_BODY
@@ -482,7 +482,7 @@ RET_UDP_LISTENER = {
         'id': 'sample_pool_id_1',
         'enabled': True,
         'health_monitor': RET_UDP_HEALTH_MONITOR,
-        'lb_algorithm': 'rr',
+        'lb_algorithm': 'wrr',
         'members': [UDP_MEMBER_1, UDP_MEMBER_2],
         'protocol': 'udp',
         'session_persistence': UDP_SOURCE_IP_BODY
@@ -609,7 +609,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           backend_tls_versions=constants.
                           TLS_VERSIONS_OWASP_SUITE_B,
                           alpn_protocols=constants.
-                          AMPHORA_SUPPORTED_ALPN_PROTOCOLS):
+                          AMPHORA_SUPPORTED_ALPN_PROTOCOLS,
+                          sample_default_pool=1,
+                          pool_enabled=True):
     proto = 'HTTP' if proto is None else proto
     if be_proto is None:
         be_proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
@@ -646,7 +648,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
-                tls_versions=backend_tls_versions),
+                tls_versions=backend_tls_versions,
+                enabled=pool_enabled),
             sample_pool_tuple(
                 proto=be_proto, monitor=monitor, persistence=persistence,
                 persistence_type=persistence_type,
@@ -657,7 +660,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
-                tls_versions=None)]
+                tls_versions=None,
+                enabled=pool_enabled)]
         l7policies = [
             sample_l7policy_tuple('sample_l7policy_id_1', sample_policy=1),
             sample_l7policy_tuple('sample_l7policy_id_2', sample_policy=2),
@@ -682,7 +686,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
-                tls_versions=backend_tls_versions)]
+                tls_versions=backend_tls_versions,
+                enabled=pool_enabled)]
         l7policies = []
     listener = in_listener(
         id=id,
@@ -706,7 +711,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
             pool_ca_cert=pool_ca_cert,
             pool_crl=pool_crl,
             tls_enabled=tls_enabled,
-            hm_host_http_check=hm_host_http_check
+            hm_host_http_check=hm_host_http_check,
+            sample_pool=sample_default_pool,
+            enabled=pool_enabled
         ) if alloc_default_pool else '',
         connection_limit=connection_limit,
         tls_certificate_id='cont_id_1' if tls else '',
@@ -795,7 +802,8 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                       provisioning_status=constants.ACTIVE,
                       tls_ciphers=constants.CIPHERS_OWASP_SUITE_B,
                       tls_versions=constants.TLS_VERSIONS_OWASP_SUITE_B,
-                      lb_algorithm=constants.LB_ALGORITHM_ROUND_ROBIN):
+                      lb_algorithm=constants.LB_ALGORITHM_ROUND_ROBIN,
+                      enabled=True):
     proto = 'HTTP' if proto is None else proto
     if not tls_enabled:
         tls_ciphers = None
@@ -818,7 +826,15 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                   'persistence_cookie': persistence_cookie}
     persis = sample_session_persistence_tuple(**kwargs)
     mon = None
-    if sample_pool == 1:
+    if sample_pool == 0:
+        id = 'sample_pool_id_0'
+        members = []
+        if monitor is True:
+            mon = sample_health_monitor_tuple(
+                proto=monitor_proto,
+                host_http_check=hm_host_http_check,
+                expected_codes=monitor_expected_codes)
+    elif sample_pool == 1:
         id = 'sample_pool_id_1'
         members = [sample_member_tuple('sample_member_id_1', '10.0.0.99',
                                        monitor_ip_port=monitor_ip_port),
@@ -847,7 +863,7 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         members=members,
         health_monitor=mon,
         session_persistence=persis if persistence is True else None,
-        enabled=True,
+        enabled=enabled,
         operating_status='ACTIVE', has_http_reuse=has_http_reuse,
         tls_certificate_id='pool_cont_1' if pool_cert else None,
         ca_tls_certificate_id='pool_ca_1' if pool_ca_cert else None,
